﻿/*
 * Copyright (C)  2012  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace plexdata.LineCounter
{
    public partial class CommentSchemeDialog : Form
    {
        private const string IgnoreCaseYes = "Ignore Cases";
        private const string IgnoreCaseNo = "Irrelevant";

        public CommentSchemeDialog()
            : this(null)
        {
        }

        public CommentSchemeDialog(CommentScheme commentScheme)
            : base()
        {
            this.InitializeComponent();
            this.Icon = Icon.FromHandle(global::plexdata.LineCounter.Properties.Resources.FilterIcon.GetHicon());

            if (commentScheme == null)
            {
                this.CommentScheme = new CommentScheme();
            }
            else
            {
                this.CommentScheme = commentScheme.Clone() as CommentScheme;
            }
        }

        public CommentScheme CommentScheme { get; private set; }

        private void OnCommentSchemeDialogLoad(object sender, EventArgs args)
        {
            this.txtOpen.Text = this.CommentScheme.Open;
            this.txtClose.Text = this.CommentScheme.Close;

            this.btnOk.Enabled = !String.IsNullOrEmpty(this.txtOpen.Text.Trim());
            this.chkEndOfLine.Checked = this.CommentScheme.EndOfLine;
            this.chkWhitespace.Checked = this.CommentScheme.Whitespace;

            this.UpdateEndOfLineValue();
            this.UpdateLetterCheckValue();
        }

        private void OnOkButtonClick(object sender, EventArgs args)
        {
            this.CommentScheme.Open = this.txtOpen.Text;
            this.CommentScheme.Close = this.txtClose.Text;
            this.CommentScheme.Whitespace = this.chkWhitespace.Checked;
        }

        private void OnOpenTextChanged(object sender, EventArgs args)
        {
            this.btnOk.Enabled = !String.IsNullOrEmpty(this.txtOpen.Text.Trim());
            this.UpdateLetterCheckValue();
        }

        private void OnCloseTextChanged(object sender, EventArgs args)
        {
            this.UpdateLetterCheckValue();
        }

        private void OnCloseLeave(object sender, EventArgs args)
        {
            this.UpdateEndOfLineValue();

        }

        private void OnEndOfLineCheckedChanged(object sender, EventArgs args)
        {
            this.txtClose.Enabled = !this.chkEndOfLine.Checked;

            if (this.txtClose.Enabled)
            {
                this.txtClose.Focus();
            }
            else
            {
                this.txtClose.Text = String.Empty;
            }
        }

        private void UpdateEndOfLineValue()
        {
            CommentScheme helper = new CommentScheme();

            helper.Open = this.txtOpen.Text;
            helper.Close = this.txtClose.Text;

            bool endOfLine = helper.EndOfLine;

            this.chkEndOfLine.Checked = endOfLine;
            this.txtClose.Enabled = !endOfLine;

            if (endOfLine)
            {
                this.txtClose.Text = String.Empty;
            }
        }

        private void UpdateLetterCheckValue()
        {
            CommentScheme helper = new CommentScheme();

            helper.Open = this.txtOpen.Text;
            helper.Close = this.txtClose.Text;

            this.lblLetterCheckValue.Text = helper.IgnoreCase ?
                CommentSchemeDialog.IgnoreCaseYes : CommentSchemeDialog.IgnoreCaseNo;
        }
    }
}
