﻿/*
 * Copyright (C)  2012  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.Windows.Forms;
using System.ComponentModel;

namespace plexdata.LineCounter
{
    public class DetailsView : Panel
    {
        private class DetailsDisplay : WebBrowser
        {
            public DetailsDisplay()
                : base()
            {
                this.DoubleBuffered = true;
                this.WebBrowserShortcutsEnabled = false;
                this.IsWebBrowserContextMenuEnabled = false;
            }

            public void SetDocumentText(string html)
            {
                // Now that's a stubborn component!

                if (String.IsNullOrEmpty(html))
                {
                    html = String.Empty;
                }

                if (this.Document != null)
                {
                    this.Document.OpenNew(true);
                    this.Document.Write(html);
                }
                this.DocumentText = html;
            }
        }

        private DetailsDisplay display = null;
        private BorderStyle borderStyle = BorderStyle.Fixed3D;

        public DetailsView()
            : base()
        {
            this.DoubleBuffered = true;

            this.display = new DetailsDisplay();
            this.Controls.Add(display);
            this.display.Dock = DockStyle.Fill;
            this.display.TabStop = false;
        }

        public void LoadData(ScanningResult scanningResult)
        {
            this.display.SetDocumentText(
                ReportGenerator.GetDisplayReport(scanningResult));
        }

        public void ClearData()
        {
            this.display.SetDocumentText(null);
        }

        [DefaultValue(BorderStyle.Fixed3D)]
        [RefreshProperties(RefreshProperties.All)]
        public new BorderStyle BorderStyle
        {
            get { return this.borderStyle; }
            set
            {
                if (this.borderStyle != value)
                {
                    this.borderStyle = value;
                    this.Invalidate();
                }
            }
        }

        protected override CreateParams CreateParams
        {
            get
            {
                // Very smart because client rectangle is also adjusted! 
                // See also: http://support.microsoft.com/kb/316574
                const int WS_BORDER = unchecked((int)0x00800000);
                const int WS_EX_STATICEDGE = unchecked((int)0x00020000);

                CreateParams createParams = base.CreateParams;
                createParams.ExStyle &= (~WS_EX_STATICEDGE);
                createParams.Style &= (~WS_BORDER);

                switch (this.BorderStyle)
                {
                    case BorderStyle.Fixed3D:
                        createParams.ExStyle |= WS_EX_STATICEDGE;
                        break;
                    case BorderStyle.FixedSingle:
                        createParams.Style |= WS_BORDER;
                        break;
                }
                return createParams;
            }
        }
    }
}
