﻿/*
 * Copyright (C)  2012  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.IO;
using System.Linq;
using System.Diagnostics;
using System.Windows.Forms;
using System.Collections.Generic;

namespace plexdata.LineCounter
{
    public class FileSelectorDialog : ItemSelectorDialog
    {
        public FileSelectorDialog()
            : base()
        {
            this.Text += " Files";

            this.Pattern = null; // Causes *.* pattern.

            this.Load += this.OnDialogFormLoad;
            this.FormClosed += this.OnDialogFormClosed;
        }

        public FileSelectorDialog(string basePath)
            : this()
        {
            base.BasePath = basePath;
        }

        public FileSelectorDialog(string basePath, string[] pattern)
            : this(basePath)
        {
            this.Pattern = pattern;
        }

        public FileSelectorDialog(string basePath, string[] pattern, string[] selectedItems)
            : this(basePath, pattern)
        {
            base.SelectedItems = selectedItems;
        }

        private string[] pattern = null;
        public string[] Pattern
        {
            get { return this.pattern; }
            set
            {
                this.pattern = (value != null && value.Length > 0) ? value : new string[] { "*.*" };
            }
        }

        #region Dialog form event handlers.

        private void OnDialogFormLoad(object sender, EventArgs args)
        {
            // Don't use FormWindowState for a dialog window!

            // Set size before location because location depends on size!
            this.Size = Settings.Instance.FileSelectorWindow.Size;
            this.Location = Settings.Instance.FileSelectorWindow.Location;
        }

        private void OnDialogFormClosed(object sender, FormClosedEventArgs args)
        {
            // Don't use FormWindowState for a dialog window!

            // Set size before location because location depends on size!
            Settings.Instance.FileSelectorWindow.Size = this.Size;
            Settings.Instance.FileSelectorWindow.Location = this.Location;
        }

        #endregion // Dialog form event handlers.

        protected override void ScanFolder(string parent)
        {
            if (!String.IsNullOrEmpty(parent))
            {
                if (this.Pattern != null)
                {
                    foreach (string pattern in this.Pattern)
                    {
                        // Additional list filtering is necessary because 
                        // of the fact that function GetFiles() returns one 
                        // and the same file twice when the file pattern 
                        // "look" similar, like *.htm and *.html. Damn shit.
                        base.AddListItems(Directory.GetFiles(parent, pattern).Where(
                            item => String.Compare(Path.GetExtension(item),
                                Path.GetExtension(pattern), true) == 0).ToArray<string>());
                    }
                }

                foreach (string folder in Directory.GetDirectories(parent))
                {
                    this.ScanFolder(folder);
                }
            }
        }
    }
}
