﻿/*
 * Copyright (C)  2012  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.Xml.Serialization;

namespace plexdata.LineCounter
{
    public class LineCounterEnvironment
    {
        public LineCounterEnvironment()
            : base()
        {
            this.FolderMode = false;
            this.BasePath = String.Empty;
            this.LastGroup = String.Empty;
            this.SelectedFolders = null;
            this.SelectedFiles = null;
            this.GroupCollection = new FileFilterGroupCollection();
        }

        public LineCounterEnvironment(FileFilterGroupCollection collection)
            : this()
        {
            this.GroupCollection = collection;
        }

        public bool FolderMode { get; set; }

        public string BasePath { get; set; }

        public string LastGroup { get; set; }

        private string[] selectedFolders = null;
        public string[] SelectedFolders
        {
            get
            {
                return this.selectedFolders;
            }
            set
            {
                if (value == null)
                {
                    this.selectedFolders = new string[] { };
                }
                else
                {
                    this.selectedFolders = value;
                }
            }
        }

        [XmlIgnore]
        public bool IsSelectedFolders
        {
            get { return this.selectedFolders != null && this.selectedFolders.Length > 0; }
        }

        private string[] selectedFiles = null;
        public string[] SelectedFiles
        {
            get
            {
                return this.selectedFiles;
            }
            set
            {
                if (value == null)
                {
                    this.selectedFiles = new string[] { };
                }
                else
                {
                    this.selectedFiles = value;
                }
            }
        }

        [XmlIgnore]
        public bool IsSelectedFiles
        {
            get { return this.selectedFiles != null && this.selectedFiles.Length > 0; }
        }

        public FileFilterGroupCollection GroupCollection { get; set; }
    }
}
