﻿/*
 * Copyright (C)  2012  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.Collections.Generic;

namespace plexdata.Utilities
{
    public class NamedObject : Object, IComparable, IComparable<string>, IComparable<NamedObject>, IComparer<string>, IComparer<NamedObject>
    {
        public NamedObject()
            : base()
        {
            this.Name = String.Empty;
            this.Description = String.Empty;
            this.Tooltip = String.Empty;
            this.Tag = null;
        }

        public NamedObject(string name)
            : this()
        {
            this.Name = name;
        }

        public NamedObject(string name, string description)
            : this(name)
        {
            this.Description = description;
        }

        public NamedObject(string name, string description, string tooltip)
            : this(name, description)
        {
            this.Tooltip = tooltip;
        }

        private string name = null;
        public virtual string Name
        {
            get
            {
                if (this.name != null)
                {
                    return this.name;
                }
                else
                {
                    return String.Empty;
                }
            }
            set
            {
                if (value != this.name)
                {
                    this.name = !String.IsNullOrEmpty(value) ? value : String.Empty;
                }
            }
        }

        private string description = null;
        public virtual string Description
        {
            get
            {
                if (this.description != null)
                {
                    return this.description;
                }
                else
                {
                    return String.Empty;
                }
            }
            set
            {
                if (value != this.description)
                {
                    this.description = !String.IsNullOrEmpty(value) ? value : String.Empty;
                }
            }
        }

        private string tooltip = null;
        public virtual string Tooltip
        {
            get
            {
                if (this.tooltip != null)
                {
                    return this.tooltip;
                }
                else
                {
                    return String.Empty;
                }
            }
            set
            {
                if (value != this.tooltip)
                {
                    this.tooltip = !String.IsNullOrEmpty(value) ? value : String.Empty;
                }
            }
        }

        public virtual object Tag { get; set; }

        public int CompareTo(object other)
        {
            if (other is string)
            {
                return this.CompareTo(other as string);
            }
            else if (other is NamedObject)
            {
                return this.CompareTo(other as NamedObject);
            }
            else
            {
                throw new ArgumentException();
            }
        }

        public int CompareTo(string other)
        {
            if (!String.IsNullOrEmpty(other))
            {
                return String.Compare(this.Name, other);
            }
            else
            {
                throw new ArgumentException();
            }
        }

        public int CompareTo(NamedObject other)
        {
            if (other != null)
            {
                return String.Compare(this.Name, other.Name);
            }
            else
            {
                throw new ArgumentNullException();
            }
        }

        public int Compare(string left, string right)
        {
            return String.Compare(left, right);
        }

        public int Compare(NamedObject left, NamedObject right)
        {
            if (left != null && right != null)
            {
                return this.Compare(left.Name, right.Name);
            }
            else if (left == null && right != null)
            {
                return -1;
            }
            else if (left != null && right == null)
            {
                return 1;
            }
            else
            {
                throw new ArgumentNullException();
            }
        }

        public override string ToString()
        {
            return String.Format(
                "Name: {0}, Description: {1}, Tooltip: {2}, Tag: {3}",
                String.IsNullOrEmpty(this.Name) ? "<empty>" : this.Name,
                String.IsNullOrEmpty(this.Description) ? "<empty>" : this.Description,
                String.IsNullOrEmpty(this.Tooltip) ? "<empty>" : this.Tooltip,
                (this.Tag == null ? "<null>" : this.Tag.ToString()));
        }
    }
}
