﻿/*
 * Copyright (C)  2012  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.IO;
using System.Reflection;
using System.Diagnostics;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace plexdata.LineCounter
{
    static class Program
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);
            Application.Run(new MainForm());
        }

        internal static void ShowHelp()
        {
            try
            {
                string location = Assembly.GetExecutingAssembly().Location;
                string helpfile = Path.Combine(
                    Path.GetDirectoryName(location),
                    Path.GetFileNameWithoutExtension(location) + ".chm");

                // Works find but the help window stays on top in z-order!
                // Help.ShowHelp(null, helpfile, HelpNavigator.TableOfContents);

                // Works fine too but the help window does not terminate
                // automatically when the appliation is closed.
                // Process help = new Process();
                // help.StartInfo.FileName = helpfile;
                // help.Start();

                // Nevertheless, each solution above is not perfect! So we need to 
                // call HtmlHelp() function directly because it solves all problems!
                Program.HtmlHelp(IntPtr.Zero, helpfile, Program.HH_DISPLAY_TOC, IntPtr.Zero);
            }
            catch (Exception exception)
            {
                Debug.WriteLine(exception);
            }
        }

        #region HtmlHelp import stuff.

        // See file "htmlhelp.h" and http://support.microsoft.com/kb/317406

        private const uint HH_DISPLAY_TOPIC = 0x0000;
        private const uint HH_HELP_FINDER = 0x0000;
        private const uint HH_DISPLAY_TOC = 0x0001;
        private const uint HH_DISPLAY_INDEX = 0x0002;
        private const uint HH_DISPLAY_SEARCH = 0x0003;

        [DllImport("hhctrl.ocx", CharSet = CharSet.Auto)]
        private static extern IntPtr HtmlHelp(IntPtr hCaller, String helpfile, uint command, IntPtr data);

        #endregion // HtmlHelp import stuff.
    }
}
