﻿/*
 * Copyright (C)  2012  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.Windows.Forms;

namespace plexdata.LineCounter
{
    internal class ResultsTabControl : TabControl
    {
        public ResultsTabControl()
            : base()
        {
            // It doesn't really have an effect according to a flicker free drawing.
            this.SetStyle(ControlStyles.OptimizedDoubleBuffer | ControlStyles.AllPaintingInWmPaint, true);
            this.UpdateStyles();
        }

        public void Initialize(ScanningResults scanningResults)
        {
            this.Cleanup();

            SummaryTabPage summary = (this.SelectedTab as SummaryTabPage);
            if (summary == null)
            {
                summary = new SummaryTabPage();
                this.TabPages.Add(summary);
            }
            summary.Initialize(scanningResults);

            foreach (ScanningResult current in scanningResults.TypeResults)
            {
                this.TabPages.Add(new ResultsTabPage(current));
            }
        }

        public void Cleanup()
        {
            for (int index = 0; index < this.TabPages.Count; index++)
            {
                TabPage current = this.TabPages[index];

                if (current is SummaryTabPage)
                {
                    (current as SummaryTabPage).Cleanup();
                    continue;
                }

                this.TabPages.Remove(current);
                index--;
            }

            if (this.Controls.Count > 0) { this.SelectedIndex = 0; }
        }
    }

    internal class ResultsTabPage : TabPage
    {
        protected ResultPanel resultPanel = null;

        public ResultsTabPage()
            : base()
        {
            // It doesn't really have an effect according to a flicker free drawing.
            this.SetStyle(ControlStyles.OptimizedDoubleBuffer | ControlStyles.AllPaintingInWmPaint, true);
            this.UpdateStyles();

            this.Name = "tabResult";
            this.Text = "";

            this.Padding = new Padding(0);
            this.resultPanel = new ResultPanel();
            this.resultPanel.Dock = DockStyle.Fill;
            this.resultPanel.Name = "panResult";
            this.Controls.Add(this.resultPanel);

            this.Initialize(null);
        }

        public ResultsTabPage(ScanningResult scanningResult)
            : this()
        {
            this.Initialize(scanningResult);
        }

        private void Initialize(ScanningResult scanningResult)
        {
            if (scanningResult != null)
            {
                this.Text = scanningResult.Label;
                this.resultPanel.Initialize(scanningResult);
            }
        }

        public void Cleanup()
        {
            this.resultPanel.Cleanup();
        }
    }

    internal class SummaryTabPage : ResultsTabPage
    {
        public SummaryTabPage()
            : base()
        {
            this.Name = "tabSummary";
            this.resultPanel.Name = "panSummary";
        }

        public void Initialize(ScanningResults scanningResults)
        {
            if (scanningResults != null)
            {
                this.Text = scanningResults.Label;
                this.resultPanel.Initialize(scanningResults as ScanningResult);
            }
        }
    }
}
